@@ -10,12 +10,15 @@ forgotten) from the programmer.
 #include "windows.h"
 
 /* NT and Python share these */
-#undef INCREF
-#undef DECREF
-#include "config.h"
-#include "allobjects.h"
+#include "pyconfig.h"
+#include "Python.h"
 
+char dllVersionBuffer[16] = ""; // a private buffer
+
+// Python Globals
 HMODULE PyWin_DLLhModule = NULL;
+const char *PyWin_DLLVersionString = dllVersionBuffer;
+
 
 BOOL	WINAPI	DllMain (HANDLE hInst, 
 						ULONG ul_reason_for_call,
@@ -25,7 +28,9 @@ BOOL	WINAPI	DllMain (HANDLE hInst,
 	{
 		case DLL_PROCESS_ATTACH:
 			PyWin_DLLhModule = hInst;
-			initall();
+			// 1000 is a magic number I picked out of the air.  Could do with a #define, I spose...
+			LoadString(hInst, 1000, dllVersionBuffer, sizeof(dllVersionBuffer));
+			//initall();
 			break;
 		case DLL_PROCESS_DETACH:
 			break;
